import 'package:cpt_rewards/modules/rewards_transaction/rewards_transaction_page.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/widget_export.dart';
import 'package:cs_resources/generated/assets.dart';

import '../../../router/page/rewards_page_router.dart';
import './rewards_history_spent_vm.dart';

@RoutePage()
class RewardsHistorySpentPage extends HookConsumerWidget {
  const RewardsHistorySpentPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context}) {
    if (context != null) {
      context.router.push(const RewardsHistorySpentPageRoute());
    } else {
      appRouter.push(const RewardsHistorySpentPageRoute());
    }
  }

  // listitem
  Widget _buildSaleItem(BuildContext context, WidgetRef ref, item, _vm) {
    return Container(
      padding: const EdgeInsets.only(top: 15, bottom: 15, left: 18, right: 18),
      decoration: BoxDecoration(
          border: Border(
              bottom: BorderSide(
        width: 1.0, // 底边边框的宽度
        color: ColorUtils.string2Color('#F2F3F6'), // 底边边框的颜色
      ))),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Text(
                'Daily Login',
                style: TextStyle(
                    fontSize: 15.0,
                    color: ColorUtils.string2Color('#000000'),
                    fontWeight: FontWeight.w500), // 设置字体大小
              ).marginOnly(bottom: 6),
              Text(
                '14 Oct 2024  10:00PM',
                style: TextStyle(
                    fontSize: 13.0,
                    color: ColorUtils.string2Color('#808DAF'),
                    fontWeight: FontWeight.w400), // 设置字体大小
              ),
            ],
          ),
          Text(
            '-4.500',
            style: TextStyle(
                fontSize: 20.0,
                color: ColorUtils.string2Color('#4161D0'),
                fontWeight: FontWeight.w500), // 设置字体大小
          ),
        ],
      ),
    );
  }

  // list
  Widget _buildSaleList(BuildContext context, WidgetRef ref, _vm) {
    List itemsList = _vm.state.list.toList();
    return Container(
        decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.circular(10),
          boxShadow: const [
            BoxShadow(color: Color.fromRGBO(184, 191, 217, 0.3), blurRadius: 6)
          ],
        ),
        child:
            // Column(
            //     crossAxisAlignment: CrossAxisAlignment.center,
            //     mainAxisAlignment: MainAxisAlignment.center,
            //     children: [
            ListView.builder(
          itemCount: itemsList.length,
          itemBuilder: (context, index) {
            return _buildSaleItem(context, ref, itemsList[index], _vm);
          },
        )
        // ])
        );
  }

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final _vm = ref.read(rewardsHistorySpentVmProvider.notifier);

    return Scaffold(
      // appBar: AppBar(title: Text("资产")),
      body: Container(
        color: ColorUtils.string2Color('#F2F3F6'),
        padding: const EdgeInsets.only(top: 15, left: 15, right: 15),
        child: EasyRefresh(
          // 上拉加载
          onLoad: () async {
            Log.d("----onLoad");
            _vm.onLoadData();
          },
          // 下拉刷新
          onRefresh: () async {
            Log.d("----onRefresh");
            _vm.refreshListData();
          },
          child: Container(
              // color: ColorUtils.string2Color('#F2F3F6'),
              // padding: const EdgeInsets.only(top: 15, left: 15, right: 15),
              child: _buildSaleList(context, ref, _vm)),
        ),
      ),
    );
  }
}
