import 'package:cpt_rewards/modules/rewards_transaction/rewards_transaction_page.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/widget_export.dart';
import 'package:cs_resources/generated/assets.dart';

import '../../../router/page/rewards_page_router.dart';
import './rewards_my_used_vm.dart';

@RoutePage()
class RewardsMyUsedPage extends HookConsumerWidget {
  const RewardsMyUsedPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context}) {
    if (context != null) {
      context.router.push(const RewardsMyUsedPageRoute());
    } else {
      appRouter.push(const RewardsMyUsedPageRoute());
    }
  }

  Widget _buildItemLeftSection(BuildContext context, WidgetRef ref, item, _vm) {
    return Column(
      children: [
        Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const Text(
              maxLines: 1, // 设置最大行数为2
              overflow: TextOverflow.ellipsis, // 超出部分用省略号表示
              'Cute children multifunctional ……',
              style: TextStyle(
                  fontSize: 16.0,
                  color: Colors.black,
                  fontWeight: FontWeight.w500),
            ),
            Row(
              children: [
                const Text(
                  '300',
                  style: TextStyle(
                      fontSize: 19.0,
                      color: Colors.black,
                      fontWeight: FontWeight.w500),
                ),
                Text(
                  '350',
                  style: TextStyle(
                      decoration: TextDecoration.lineThrough,
                      decorationColor: ColorUtils.string2Color('#000000'),
                      decorationStyle: TextDecorationStyle.solid,
                      fontSize: 12.0,
                      color: ColorUtils.string2Color('#000000'),
                      fontWeight: FontWeight.w400),
                ).marginOnly(left: 5, right: 5),
                const Text(
                  'Points',
                  style: TextStyle(
                      fontSize: 13.0,
                      color: Colors.black,
                      fontWeight: FontWeight.w400),
                ),
              ],
            ),
            Row(
              children: [
                const MyAssetImage(
                  Assets.rewardsRewardsIconDatd,
                  width: 15,
                  height: 15,
                ),
                const Text(
                  'Redeem From: 17 Mar 2024 until 15 Jul 2024',
                  style: TextStyle(
                      fontSize: 13.0,
                      color: Colors.black,
                      fontWeight: FontWeight.w400),
                ).marginOnly(left: 6)
              ],
            ).paddingOnly(left: 6),
            Row(
              children: [
                const MyAssetImage(
                  Assets.rewardsRewardsIconDraw,
                  width: 15,
                  height: 15,
                ),
                const Text(
                  'Redeemed at: 2 July 2014, 17:23',
                  style: TextStyle(
                      fontSize: 13.0,
                      color: Colors.black,
                      fontWeight: FontWeight.w400),
                ).marginOnly(left: 6)
              ],
            ).paddingOnly(left: 6),
            Container(
                height: 43,
                decoration: BoxDecoration(
                  color: ColorUtils.string2Color('#4161D0'),
                  borderRadius: BorderRadius.circular(8), // 圆角
                ),
                child: Expanded(
                    child: Container(
                        alignment: Alignment.center,
                        child: Text(
                          'View',
                          style: TextStyle(
                              fontSize: 15.0,
                              color: ColorUtils.string2Color('#FFFFFF'),
                              fontWeight: FontWeight.w500),
                        )))).marginOnly(top: 10, bottom: 5).onTap(() {
              RewardsTransactionPage.startInstance();
            }),
          ],
        ),
        const MyAssetImage(
          Assets.rewardsRewardsIndex1,
          // width: 110,
          height: 133,
        ),
      ],
    ).paddingOnly(top: 20).onTap(() {
      // 去详情
      RewardsTransactionPage.startInstance();
    });
  }

  Widget _buildItemRightSection(
      BuildContext context, WidgetRef ref, item, _vm) {
    return Container(
      // color: Colors.green,
      child: Text(
        item['price'],
        style: const TextStyle(
            fontSize: 14.0,
            color: Colors.black,
            fontWeight: FontWeight.w400), // 设置字体大小
      ),
    );
  }

  // listitem
  Widget _buildSaleItem(BuildContext context, WidgetRef ref, item, _vm) {
    return Container(
      decoration: const BoxDecoration(
        color: Colors.white,
        borderRadius: BorderRadius.all(Radius.circular(6.0)),
        boxShadow: [
          BoxShadow(color: Color.fromRGBO(184, 191, 217, 0.3), blurRadius: 6)
        ],
      ),
      child: Column(
        children: [
          SizedBox(
            width: MediaQuery.of(context).size.width - 30,
            height: 302,
            // margin: const EdgeInsets.only(left: 15, right: 15, top: 12.5),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                _buildItemLeftSection(context, ref, item, _vm)
                // .marginOnly(bottom: 5),
                // _buildItemRightSection(context, ref, item, _vm),
              ],
            ).paddingOnly(left: 20, right: 20),
          ).constrained(
            minHeight: 300.5,
          ),
        ],
      ),
    ).marginOnly(left: 15, bottom: 15, right: 15);
  }

  // list
  Widget _buildSaleList(BuildContext context, WidgetRef ref, _vm) {
    List itemsList = _vm.state.list.toList();
    return ListView.builder(
      itemCount: itemsList.length,
      itemBuilder: (context, index) {
        return _buildSaleItem(context, ref, itemsList[index], _vm);
      },
    );
  }

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final _vm = ref.read(rewardsMyUsedVmProvider.notifier);

    return Scaffold(
      // appBar: AppBar(title: Text("资产")),
      body: EasyRefresh(
        // 上拉加载
        onLoad: () async {
          Log.d("----onLoad");
          _vm.onLoadData();
        },
        // 下拉刷新
        onRefresh: () async {
          Log.d("----onRefresh");
          _vm.refreshListData();
        },
        child: Container(
            color: ColorUtils.string2Color('#F2F3F6'),
            padding: const EdgeInsets.only(top: 15),
            child: _buildSaleList(context, ref, _vm)),
      ),
    );
  }
}
